import 'package:image/image.dart';
import 'package:meta/meta.dart';
import 'package:ricky_icon_generator/core/logger.dart';
import '../../core/models/icon_template_model.dart';
import '../../core/base_controller.dart';

abstract class BaseAppIconController<T extends IconTemplateModel> extends BaseController<T> {
  @protected
  Image customSourceImage;

  @protected
  String? backgroundColor;

  @protected
  double resizePercentage;

  BaseAppIconController({this.backgroundColor, required this.customSourceImage, double? resizePercentage})
      : assert(resizePercentage == null || resizePercentage <= 1),
        resizePercentage = resizePercentage ?? 1;

  BaseAppIconController.custom({this.backgroundColor, required this.customSourceImage, required this.resizePercentage, errorHandler, rootPath})
      : assert(resizePercentage <= 1),
        super.custom(errorHandler: errorHandler, rootPath: rootPath);

  @protected
  List<T> get appIconList;

  @protected
  void generateAppIcon();

  @protected
  void executeConfigurationProcess();

  @override
  Future<bool> execute() {
    try {
      generateAppIcon();
      executeConfigurationProcess();
      return Future.value(true);
    } on Exception catch (e, _) {
      if (errorHandler != null) {
        errorHandler!(e);
      }
      Logger.error(message: e.toString());
    }
    return Future.value(false);
  }
}
