import 'package:image/image.dart';
import 'package:meta/meta.dart';
import 'package:ricky_icon_generator/core/logger.dart';
import '../../core/base_controller.dart';
import '../../core/models/icon_template_model.dart';

abstract class BaseSplashController<T extends IconTemplateModel> extends BaseController<T> {
  @protected
  Image customSourceImage;

  @protected
  String? backgroundColor;

  @protected
  final double resizePercentage;

  BaseSplashController({this.backgroundColor, required this.customSourceImage, double? resizePercentage})
      : assert(resizePercentage == null || resizePercentage <= 2),
        resizePercentage = resizePercentage ?? 1;

  BaseSplashController.custom(
      {required this.backgroundColor, required this.customSourceImage, required this.resizePercentage, errorHandler, rootPath})
      : assert(resizePercentage <= 2),
        super.custom(errorHandler: errorHandler, rootPath: rootPath);

  @protected
  List<T> get splashIconList;

  @protected
  bool get hasDarkMode => false;

  @protected
  void generateSplashLogo();

  @protected
  void applySplashBackground();

  @override
  Future<bool> execute() {
    try {
      applySplashBackground();
      generateSplashLogo();

      return Future.value(true);
    } on Exception catch (message, _) {
      Logger.error(message: message);
    }
    return Future.value(false);
  }
}
